.. currentmodule:: gedidb

.. _api:

API Reference
=============

This page provides an auto-generated summary of gediDB’s API. For more details and examples, refer to the relevant chapters in the main part of the documentation.

Top-level functions
===================

.. autosummary::
   :toctree: generated/
   :recursive:

   GEDIDatabase
   GEDIGranule
   GEDIProcessor
   GEDIProvider

Downloading functions
=====================

.. autosummary::
   :toctree: generated/
   :recursive:

   GEDIDownloader
   CMRDataDownloader
   H5FileDownloader
   EarthDataAuthenticator
   CMRQuery
   
GEDI data processing functions
==============================

.. autosummary::
   :toctree: generated/
   :recursive:

   granule_handler
   GranuleParser
   L2AGranule
   L2BGranule
   L4AGranule
   L4CGranule 
   beam_handler
   L2ABeam
   L2BBeam
   L4ABeam
   L4CBeam
   GediNameMetadata
   
TileDB functions
=======================

.. autosummary::
   :toctree: generated/
   :recursive:

   TileDBProvider
   SpatialConsolidationPlan
   SpatialConsolidationPlanner

   



   